# Scoring of Process & Outcome Over Time, Absolute Distance, ULinOP
library(data.table)
library(lme4)
UnCache(all=TRUE)

abs_ulinop <- fread("/Users/pavel/Dropbox/Accountability Paper/Drafts/20170915_ALTV_datasets/abs_ulinop_day.csv")
bs_ulinop <-  fread("/Users/pavel/Dropbox/Accountability Paper/Drafts/20170915_ALTV_datasets/brier_ulinop_day.csv")

str(abs_ulinop)
#abs_ulinop <- bs_ulinop 

abs_ulinop <- abs_ulinop[, min_date:=min(date), by=ifp_id]
abs_ulinop$days_start <- as.numeric(difftime(abs_ulinop$date, abs_ulinop$min_date, units = "days"))
abs_ulinop$percent_since_start <- as.numeric(difftime(abs_ulinop$date, as.Date(kYear4Start), units = "days")) /292

abs_ulinop <- abs_ulinop[, mean_percent_per_ifp:=mean(percent_since_start), by="ifp_id"]
abs_ulinop <- abs_ulinop[, min_percent:=min(percent_since_start), by="ifp_id"]
abs_ulinop <- abs_ulinop[, max_percent:=max(percent_since_start), by="ifp_id"]
abs_ulinop$midpoint <- (abs_ulinop$max_percent + abs_ulinop$min_percent) /2


abs_ulinop$percent_within_ifp <- (abs_ulinop$percent_since_start - abs_ulinop$min_percent) / 
                         (abs_ulinop$max_percent - abs_ulinop$min_percent) 
abs_ulinop$time_within_ifp <- (abs_ulinop$percent_since_start - abs_ulinop$min_percent) 


bs_ulinop$bs_value <- bs_ulinop$value
both_ulinop <- merge(abs_ulinop, 
                     subset(bs_ulinop, select = c("ifp_id","date","method","bs_value")), 
                     by=c("ifp_id","date","method"), all.x=F, all.y=F)
setnames(both_ulinop,"value","abs_value")

# Add team, accountability labels 
both_ulinop$team <- NA
both_ulinop$team[substr(both_ulinop$method,12,12)=="1"] <- "Independent"
both_ulinop$team[substr(both_ulinop$method,12,12)=="4"] <- "Team" 

both_ulinop$Accountability <- NA
both_ulinop$Accountability[substr(both_ulinop$method,13,13)=="b"] <- "B Outcome"
both_ulinop$Accountability[substr(both_ulinop$method,13,13)=="h"] <- "Hybrid"
both_ulinop$Accountability[substr(both_ulinop$method,13,13)=="p"] <- "Process"

# Brier score
summary(lmer(bs_value ~ team + Accountability*percent_within_ifp + Accountability*mean_percent_per_ifp + 
                  (1 + percent_within_ifp|ifp_id), 
             data=both_ulinop))
# Sensitivity analysis: not recommended. 
summary(lmer(bs_value ~ team + Accountability*percent_within_ifp + Accountability*mean_percent_per_ifp + 
                  (1 + team + Accountability + percent_within_ifp|ifp_id), 
             data=both_ulinop))
# Absolute score
summary(lmer(abs_value ~ team + Accountability*percent_within_ifp + Accountability*mean_percent_per_ifp + 
                  (1 + percent_within_ifp|ifp_id), 
             data=both_ulinop))
# Sensitivity analysis: not recommended. 
summary(lmer(abs_value ~ team + Accountability*percent_within_ifp + Accountability*mean_percent_per_ifp + 
                  (1 + team + Accountability + percent_within_ifp|ifp_id), 
             data=both_ulinop))


#############################
###       FIGURE 1        ###
#############################

# Edit accountability format so that var can be used plot labels
both_ulinop$Accountability <- NULL
both_ulinop$Accountability <- NA
both_ulinop$Accountability[substr(both_ulinop$method,13,13)=="b"] <- "Outcome"
both_ulinop$Accountability[substr(both_ulinop$method,13,13)=="h"] <- "Hybrid"
both_ulinop$Accountability[substr(both_ulinop$method,13,13)=="p"] <- "Process"
both_ulinop$Accountability <- factor(both_ulinop$Accountability, ordered=TRUE, levels=c("Process","Hybrid","Outcome"))

both_ulinop_summary <- both_ulinop[, list(mean_bs=mean(bs_value, na.rm=TRUE), 
                                          mean_abs=mean(abs_value, na.rm=TRUE)), 
     								by=c("Accountability","date")]
both_ulinop_summary$date <- as.Date(both_ulinop_summary$date)

# Brier score
ggplot(both_ulinop_summary, 
			 aes(x = date , y = mean_bs, color=Accountability)) +
  geom_smooth(method = "lm", size=1.3) +
  labs( x = "Date", 
        #y = "Mean Daily Absolute Distance") +
        y = "Mean Daily Brier Score") +
  theme_bw() +  
  theme(axis.title.y = element_text(size = rel(1.5), angle = 90)) + 
  theme(axis.title.x = element_text(size = rel(1.5), angle = 00)) + 
  theme(axis.text = element_text(size = rel(1.2))) + 
  theme(legend.text  = element_text(size = rel(1.2))) + 
  theme(legend.title   = element_text(size = rel(1.2))) + 
  theme(legend.title   = element_text(size = rel(1.2))) + 
	theme(strip.text.x = element_text(size = 14)) + 
  theme(legend.title.align   = 0.5) + 	
	ylim(0,.5) + 
     #ylim(0,.5) + 
	#geom_point(size=2) +
  scale_colour_manual(values = c("blue4", "mediumpurple2", "red4"))


# Absolute score
ggplot(both_ulinop_summary, 
     		 aes(x = date , y = mean_abs, color=Accountability)) +
  geom_smooth(method = "lm", size=1.3) +
  labs( x = "Date", 
        y = "Mean Daily Absolute Distance") +
  theme_bw() +  
  theme(axis.title.y = element_text(size = rel(1.5), angle = 90)) + 
  theme(axis.title.x = element_text(size = rel(1.5), angle = 00)) + 
  theme(axis.text = element_text(size = rel(1.2))) + 
  theme(legend.text  = element_text(size = rel(1.2))) + 
  theme(legend.title   = element_text(size = rel(1.2))) + 
  theme(legend.title   = element_text(size = rel(1.2))) + 
	theme(strip.text.x = element_text(size = 14)) + 
  theme(legend.title.align   = 0.5) + 	
	ylim(0,1) + 
     #ylim(0,.5) + 
	#geom_point(size=2) +
  scale_colour_manual(values = c("blue4", "mediumpurple2", "red4"))

