# moof_merge_emily.R
# Purpose: Merge data from moof ratings, forecasts, rated comments, etc.
# Authors: Mike Bishop & Pavel Atanasov 
# Input: run moof_merge_emily.R 
library(data.table)
library(plyr)
library(dplyr)
library(psych)

# Start with all.moof, which includes MOOF forecasts, asssociated rated comments and realized outcomes
all.moof <- read.csv("/Users/pavel/Dropbox/Accountability Paper/20170915_ALTV_datasets/all_moof.csv", stringsAsFactors=FALSE)
all.moof$X <- NULL 

str(all.moof)
all.moof_pred <- subset(all.moof, !is.na(moof_forecast_id))
str(all.moof_pred)
# Count of ratings and updates
length(unique(all.moof$rating_id))

# Arrange all_moof and take lag of past prediction, to calculate update 
all.moof_pred <- arrange(all.moof_pred, ifp_id, moof_id, moof_timestamp)

length(all.moof$rating_id[!is.na(all.moof$rating_id)])
length(all.moof_pred$rating_id[!is.na(all.moof_pred$rating_id)])

all.moof_pred$moof_a_lag <- NA 
all.moof_pred$moof_id_lag <- NA 

# Take the lag forecast (last prediction before update, NA if it's the first row for a moof_id)
all.moof_pred$moof_a_lag <- c(NA, all.moof_pred$moof_a[1:(length(all.moof_pred$moof_a_lag)-1)] )
all.moof_pred$moof_id_lag <- c(NA, all.moof_pred$moof_id[1:(length(all.moof_pred$moof_id)-1)] )
all.moof_pred$moof_a_lag[all.moof_pred$moof_id_lag!=all.moof_pred$moof_id] <- NA
all.moof_pred$outcome_a <- (all.moof_pred$outcome=="a")*1

# Calculate Brier score, just for option a, this is not very precise for multinomial questions
all.moof_pred$brier_a <- 2*(all.moof_pred$moof_a - all.moof_pred$outcome_a)^2
all.moof_pred$brier_lag_a <- 2*(all.moof_pred$moof_a_lag - all.moof_pred$outcome_a)^2
# High scores denote accuracy improvement, i.e. Brier decrease from past to present 
all.moof_pred$brier_a_diff <- all.moof_pred$brier_lag_a - all.moof_pred$brier_a 
# Condition training
all.moof_pred$ct <- substr(all.moof_pred$ctt,1,2)
all.moof_pred$ct[is.na(all.moof_pred$ct)] <- "None"
all.moof_pred <- data.table(all.moof_pred)
all.moof_pred_all <- all.moof_pred

# Subset out observations without belief change 
all.moof_pred <- subset(all.moof_pred, !is.na(brier_a_diff))
all.moof_pred$cond <- substr(all.moof_pred$ct,1,1)
all.moof_pred$acc <- substr(all.moof_pred$ct,2,2)
all.moof_pred$ct <- substr(all.moof_pred$ct,1,2)

all.moof_pred_summary	<- all.moof_pred[, list(mean_bs_improvement=mean(brier_a_diff, na.rm=TRUE), 
							sum_bs_improvement = sum(brier_a_diff),
							prop_bs_improvement = mean((brier_a_diff>0)*1),
							sd_bs_improvement=sd(brier_a_diff, na.rm=TRUE), 
							n_obs = NROW(brier_a_diff)), 
							by=c("ct","user_id")]
# Binary questions only 
all.moof_pred_summary2     <- all.moof_pred[is.na(moof_c), 
                              list(mean_bs_improvement=mean(brier_a_diff, na.rm=TRUE), 
							sum_bs_improvement = sum(brier_a_diff),
							prop_bs_improvement = mean((brier_a_diff>0)*1),
							sd_bs_improvement=sd(brier_a_diff, na.rm=TRUE), 
							n_obs = NROW(brier_a_diff)), 
							by=c("ct","user_id")]


all.moof_pred_summary$cond <- substr(all.moof_pred_summary$ct,1,1)
all.moof_pred_summary$acc <- substr(all.moof_pred_summary$ct,2,2)
all.moof_pred_summary2$cond <- substr(all.moof_pred_summary2$ct,1,1)
all.moof_pred_summary2$acc <- substr(all.moof_pred_summary2$ct,2,2)

summary(aov(mean_bs_improvement ~ cond*acc, data=subset(all.moof_pred_summary2,ct!="None")))
summary(lm(mean_bs_improvement ~ cond*acc, data=subset(all.moof_pred_summary2,ct!="None")))
summary(lm(mean_bs_improvement ~ cond*acc, data=subset(all.moof_pred_summary2, ct!="None" & n_obs>10)))


# Result: No differences in persuasion value
all.moof_pred_summary$condition2 <- all.moof_pred_summary$cond
all.moof_pred_summary$condition2[all.moof_pred_summary$cond!="o"]  <- "bhp"

# all.moof_pred_summary3 is used to generat Figure 5, right panel in manuscript 
all.moof_pred_summary3	<- all.moof_pred_summary2[, list(mean_bs_improvement=mean(mean_bs_improvement, na.rm=TRUE), 
												se_bs=sd(mean_bs_improvement, na.rm=TRUE)/sqrt(length(mean_bs_improvement)),
												sum_bs_improvement = sum(sum_bs_improvement), 
												prop_bs_improvement = mean(prop_bs_improvement), 
												n_users=length(unique(user_id))),
												by=c("acc")]
#all.moof_pred_summary2_	<- all.moof_pred_summary[, list(mean_bs_improvement=mean(mean_bs_improvement, na.rm=TRUE), 
#												se_bs=sd(mean_bs_improvement, na.rm=TRUE)/sqrt(length(mean_bs_improvement)),
#												sum_bs_improvement = sum(sum_bs_improvement)),
#												by=c("condition2")]
all.moof_pred_summary$condition2 <- all.moof_pred_summary$acc
all.moof_pred_summary$condition2[all.moof_pred_summary$condition!="o"]  <- "bhp"



# Count three things 
# Number of key comment impressions and key comments per ct
str(all.moof)
all.moof$team <- substr(all.moof$ctt,1,1) 
all.moof$acc <- substr(all.moof$ctt,2,2) 
all.moof_impressions <- data.table(subset(all.moof, !is.na(rating_id)))
# End of data prep 

all.moof_kc_count <- all.moof_impressions[!is.na(ctt), list(n_key_com = length(unique(comment_id)), 
							               n_impressions = length(unique(rating_id)), 
							               n_updates = length(unique(moof_forecast_id))), 
                                                  by=c("acc")]

# all.moof_kc_count$n_updates_per_impression used to generate Figure 5, left panel, in manuscript 
all.moof_kc_count$n_updates_per_impression <- all.moof_kc_count$n_updates / all.moof_kc_count$n_impressions
all.moof_kc_count$n_non_updates <- all.moof_kc_count$n_impressions - all.moof_kc_count$n_updates

ggplot(all.moof_kc_count, 
			 aes(x = factor(acc), 
			 y = n_updates_per_impression, fill=acc)) + 
	geom_bar(stat = "identity") + 
	theme_bw() + 
	labs( title = " ",
        x = "Accountability Condition", 
        y = "Updates per Impression") +
	theme(axis.title.x = element_text(size = rel(1.5), angle = 00)) + 
  theme(axis.title.y = element_text(size = rel(1.5), angle = 90)) + 
  theme(axis.text.x  = element_text(size = rel(1.5), angle = 00)) + 
  theme(axis.text.y  = element_text(size = rel(1.5), angle = 90)) + 
  theme(legend.text  = element_text(size = rel(1.5), angle = 00)) + 
  theme(legend.title  = element_text(size = rel(1.5), angle = 00)) + 
  theme(legend.title  = element_text(size = rel(1.5), angle = 00)) + 
  scale_fill_manual(values = c("blue4", "mediumpurple2", "red4","grey60"))


# Run a model, cluster by ifp_id and forecaster (comment generator)
summary(glmer(fcast_updated ~ acc + team + (1|ifp_id) + (1|user_id), data = all.moof_impressions, 
              family = binomial(link = "logit")))


# How about accountability conditions separately?
chisq.test(subset(all.moof_kc_count, acc %in% c("b","h"), select=c("n_updates","n_non_updates")))
chisq.test(subset(all.moof_kc_count, acc %in% c("b","p"), select=c("n_updates","n_non_updates")))
chisq.test(subset(all.moof_kc_count, acc %in% c("h","p"), select=c("n_updates","n_non_updates")))

# Post-hocs not inluded in manuscript
chisq.test(subset(data.frame(all.moof_kc_count), substr(ct,1,2) %in% c("1b","1h"), select=c("n_updates","n_non_updates")))
chisq.test(subset(data.frame(all.moof_kc_count), substr(ct,1,2) %in% c("1h","1p"), select=c("n_updates","n_non_updates")))
chisq.test(subset(data.frame(all.moof_kc_count), substr(ct,1,2) %in% c("1b","1p"), select=c("n_updates","n_non_updates")))
chisq.test(subset(data.frame(all.moof_kc_count), substr(ct,1,2) %in% c("4b","4h"), select=c("n_updates","n_non_updates")))
chisq.test(subset(data.frame(all.moof_kc_count), substr(ct,1,2) %in% c("4h","4p"), select=c("n_updates","n_non_updates")))
chisq.test(subset(data.frame(all.moof_kc_count), substr(ct,1,2) %in% c("4b","4p"), select=c("n_updates","n_non_updates")))


# Count number of comments generated, for manucript text
all.moof_kc_count_person <- all.moof[!is.na(ct), list(n_key_com = length(unique(comment_id)), 
								n_impressions = length(unique(rating_id)), 
								n_updates = length(unique(moof_forecast_id))), by=c("user_id","ct")]
all.moof_kc_count_person$n_updates_per_impression <- all.moof_kc_count_person$n_updates / all.moof_kc_count_person$n_impressions

describeBy(all.moof_kc_count_person$n_updates_per_impression, all.moof_kc_count_person$ct)


